# `langchain_acp` API

This page documents the public surface re-exported by `langchain_acp`.

## Functions

::: langchain_acp.create_acp_agent

::: langchain_acp.run_acp

::: langchain_acp.compose_projection_maps

::: langchain_acp.compose_event_projection_maps

## Core Classes And Data Types

::: langchain_acp.AdapterConfig

::: langchain_acp.AcpSessionContext

::: langchain_acp.JsonValue

::: langchain_acp.TaskPlan

## Graph Source Classes And Protocols

::: langchain_acp.CompiledAgentGraph

::: langchain_acp.GraphFactory

::: langchain_acp.GraphSource

::: langchain_acp.StaticGraphSource

::: langchain_acp.FactoryGraphSource

## Session Store Classes

::: langchain_acp.SessionStore

::: langchain_acp.MemorySessionStore

::: langchain_acp.FileSessionStore

## Provider State Classes And Protocols

::: langchain_acp.ConfigOption

::: langchain_acp.ConfigOptionsProvider

::: langchain_acp.ModelSelectionState

::: langchain_acp.ModeState

::: langchain_acp.NativePlanPersistenceProvider

::: langchain_acp.PlanProvider

::: langchain_acp.SessionModelsProvider

::: langchain_acp.SessionModesProvider

## Bridge Classes

::: langchain_acp.CapabilityBridge

::: langchain_acp.BufferedCapabilityBridge

::: langchain_acp.ConfigOptionsBridge

::: langchain_acp.ModelSelectionBridge

::: langchain_acp.ModeSelectionBridge

::: langchain_acp.ToolSurfaceBridge

::: langchain_acp.DeepAgentsCompatibilityBridge

::: langchain_acp.GraphBridgeBuilder

::: langchain_acp.GraphBuildContributions

## Plan Helpers

::: langchain_acp.NativePlanGeneration

::: langchain_acp.PlanGenerationType

::: langchain_acp.acp_get_plan

::: langchain_acp.acp_mark_plan_done

::: langchain_acp.acp_set_plan

::: langchain_acp.acp_update_plan_entry

::: langchain_acp.native_plan_tools

## Projection Classes

::: langchain_acp.FileSystemProjectionMap

::: langchain_acp.DeepAgentsProjectionMap

::: langchain_acp.CompositeProjectionMap

::: langchain_acp.StructuredEventProjectionMap

::: langchain_acp.CompositeEventProjectionMap

## Projection Helpers

::: langchain_acp.build_tool_start_update

::: langchain_acp.build_tool_progress_update

::: langchain_acp.extract_tool_call_locations
